@@ -41,6 +41,7 @@
 
 #define MAX_DECRYPT_BUNDLES 16
 
+#define USE_LKCA_SPDM_APIS 1 /* Use LKCA APIs */
 static void
 ccslSplit32(NvU8 *dst, NvU32 num)
 {
@@ -392,10 +393,12 @@ static KernelChannel *getKernelChannelViaChannelHandle(NvHandle hClient, NvHandl
 
 static void openrmCtxFree(void *openrmCtx)
 {
+#if RMCFG_FEATURE_PLATFORM_UNIX && RMCFG_MODULE_SPDM && USE_LKCA_SPDM_APIS
     if (openrmCtx != NULL)
     {
         libspdm_aead_free(openrmCtx);
     }
+#endif
 }
 
 NV_STATUS
@@ -447,14 +450,17 @@ ccslContextInitViaChannel_IMPL
     }
     *ppCtx = pCtx;
 
+    pCtx->msgCounterSize = CSL_MSG_CTR_32;
     pCtx->openrmCtx = NULL;
     pCtx->pDecryptBundles = NULL;
 
+#if RMCFG_FEATURE_PLATFORM_UNIX && RMCFG_MODULE_SPDM && USE_LKCA_SPDM_APIS
     if (!libspdm_aead_gcm_prealloc(&pCtx->openrmCtx))
     {
         status = NV_ERR_NO_MEMORY;
         goto ccslContextInitViaChannelCleanup;
     }
+#endif
 
     pCtx->pDecryptBundles = portMemAllocNonPaged(sizeof(*pCtx->pDecryptBundles) * MAX_DECRYPT_BUNDLES);
     if (pCtx->pDecryptBundles == NULL)
@@ -505,7 +511,6 @@ ccslContextInitViaChannel_IMPL
 
     pCtx->pEncStatsBuffer = pKernelChannel->pEncStatsBuf;
     pCtx->pMemDesc = pMemDesc;
-    pCtx->msgCounterSize = CSL_MSG_CTR_32;
 
     // Set values only used for GSP keys to invalid
     pCtx->globalKeyIdIn  = CC_GKEYID_GEN(CC_KEYSPACE_SIZE, 0);
@@ -571,11 +576,17 @@ ccslContextInitViaKeyId_KERNEL
         return NV_ERR_NO_MEMORY;
     }
     *ppCtx = pCtx;
+
+    // Ensure all pointers are default set to NULL, in case we get out of sync with channel context values
+    portMemSet(pCtx, 0, sizeof(*pCtx));
+
+#if RMCFG_FEATURE_PLATFORM_UNIX && RMCFG_MODULE_SPDM && USE_LKCA_SPDM_APIS
     if (!libspdm_aead_gcm_prealloc(&pCtx->openrmCtx))
     {
         portMemFree(pCtx);
         return NV_ERR_NO_MEMORY;
     }
+#endif
 
     pCtx->pEncStatsBuffer = (CC_CRYPTOBUNDLE_STATS *)portMemAllocNonPaged(sizeof(CC_CRYPTOBUNDLE_STATS));
     if (pCtx->pEncStatsBuffer == NULL)
@@ -593,6 +604,7 @@ ccslContextInitViaKeyId_KERNEL
                                                      &kmb);
     if (status != NV_OK)
     {
+        portMemFree((void *)pCtx->pEncStatsBuffer);
         openrmCtxFree(pCtx->openrmCtx);
         portMemFree(pCtx);
         return status;
@@ -600,7 +612,6 @@ ccslContextInitViaKeyId_KERNEL
 
     // For now assume any call to this function uses a 64-bit message counter.
     pCtx->msgCounterSize = CSL_MSG_CTR_64;
-    pCtx->pMemDesc = NULL;
     writeKmbToContext(pCtx, &kmb, ROTATE_IV_ALL_VALID);
 
     confComputeGetKeyPairByKey(pConfCompute, globalKeyId, &pCtx->globalKeyIdOut, &pCtx->globalKeyIdIn);
@@ -848,7 +859,11 @@ ccslEncryptWithIv_IMPL
         iv[i] = encryptIv[i] ^ pCtx->ivMaskOut[i];
     }
 
+#if USE_LKCA_SPDM_APIS
     if(!libspdm_aead_aes_gcm_encrypt_prealloc(pCtx->openrmCtx,
+#else
+    if(!libspdm_aead_aes_gcm_encrypt(
+#endif
         (NvU8 *)pCtx->keyOut, CC_AES_256_GCM_KEY_SIZE_BYTES,
         iv, CC_AES_256_GCM_IV_SIZE_BYTES, aadBuffer, aadSize,
         inputBuffer, bufferSize, authTagBuffer, 16,
@@ -895,7 +910,11 @@ ccslEncrypt_KERNEL
         iv[i] = pCtx->ivOut[i] ^ pCtx->ivMaskOut[i];
     }
 
+#if USE_LKCA_SPDM_APIS
     if(!libspdm_aead_aes_gcm_encrypt_prealloc(pCtx->openrmCtx,
+#else
+    if(!libspdm_aead_aes_gcm_encrypt(
+#endif
         (NvU8 *)pCtx->keyOut, CC_AES_256_GCM_KEY_SIZE_BYTES,
         iv, CC_AES_256_GCM_IV_SIZE_BYTES, aadBuffer, aadSize,
         inputBuffer, bufferSize, authTagBuffer, 16,
@@ -993,7 +1012,11 @@ ccslDecrypt_KERNEL
         }
     }
 
+#if USE_LKCA_SPDM_APIS
     if(!libspdm_aead_aes_gcm_decrypt_prealloc(pCtx->openrmCtx,
+#else
+    if(!libspdm_aead_aes_gcm_decrypt(
+#endif
         keyIn, CC_AES_256_GCM_KEY_SIZE_BYTES,
         iv, CC_AES_256_GCM_IV_SIZE_BYTES, aadBuffer, aadSize,
         inputBuffer, bufferSize, (NvU8 *) authTagBuffer, 16,
